@@ -2,6 +2,13 @@ from django.core import signing
 
 from datetime import timedelta
 
+
+class StillSigned(ValueError):
+
+    def __init__(self, **kwargs):
+        super().__init__("Token still signed")
+
+
 class Token(object):
     """
      Represent a token used when authenticating a request toward an APIView with authentification set to True
@@ -11,9 +18,9 @@ class Token(object):
     _body = None
     _signed_data = None
 
-    def __init__(self, body:dict):
+    def __init__(self, body:dict=None, signed_data:str=None):
         self._body = body
-        self._sign_data = None
+        self._signed_data = signed_data
 
     def __str__(self):
         return self._signed_data if self.is_signed() else str(self._body)
@@ -32,3 +39,9 @@ class Token(object):
 
     def is_unsigned(self):
         return self._body is not None
+
+    @property
+    def uid(self):
+        if not self.is_unsigned():
+            raise StillSigned
+        return _body['id']
